@@ -1,13 +1,19 @@
 """
 Common test fixtures and utilities.
 """
-
-from pathlib import Path
+from dataclasses import dataclass
 from uuid import UUID
 
 from ..conftest import PY36
 
 
+@dataclass
+class SampleClass:
+    """Sample dataclass model for various test scenarios."""
+    f1: str
+    f2: int
+
+
 if PY36:
     # Ignore these files, because Python 3.6 doesn't define the `__future__`
     # import used, so we'll run into an error if we import these modules.
